## Environmental variables
## By: Mary Clinton
## Date created: March 23, 2022
## Date last modified: March 1, 2024

library(tidyverse)

# Load data 
chl_phaeo_raw <- read.csv("data/raw/ChlA_Phaeopigments.csv", header = TRUE)
CN_raw_2024 <- read.csv("data/raw/sediment_CN.csv", header = TRUE)


# Chlorophyll a & phaeopigments  ----

# Add A6650 and A6650a as columns in the data frame
# Then add column that calculates chl-a values
chl_phaeo <- chl_phaeo_raw %>% 
  mutate(
    A6650 = A665 - A750, 
    A6650a = A665a - A750a,
    chla = 26.7 * (A6650 - A6650a) * (v + (PPu - PPs)) * ((CO * Ps)^-1), # Equation 4.1 from Danovaro (2010) Ch 4
    phaeo = 26.7 * ((1.7 * A6650a) - A6650) * (v + (PPu - PPs)) * ((CO * Ps)^-1), # Equation 4.2 from Danovaro (2010) Ch 4
    chla_phaeo = chla/phaeo
  ) 

# Make summary table
chl_phaeo %>% 
  select(Site, chla, phaeo, chla_phaeo) %>% 
  group_by(Site) %>% 
  summarise(mean = across(chla:chla_phaeo, mean),
            sd = across(chla:chla_phaeo, sd))

write.csv(chl_phaeo, "data/processed/calculated_photopigment_concentrations.csv")


# Sediment carbon & nitrogen ----

# Create a summary table of %C, %N, and C:N ratio
CN_raw_2024 %>% 
  select(site, depth_layer, C, N, CN_ratio) %>% 
  group_by(site, depth_layer) %>% 
  summarise(mean = across(C:N, ~mean(., na.rm = TRUE)),
            sd = across(C:N, ~sd(., na.rm = TRUE))) %>% 
  unnest(c(mean, sd), names_sep = "_") %>% 
  mutate(CN_ratio = mean_C / mean_N)


####### END ########