#' Function to calculate diversity indices from sub-sampled cores
#'
#' @param .data A data frame containing diversity indices as columns, cores as rows
#' @param .metric A character string indicating the name of the column for diversity index you want to assess
#' @param .num_samples A integer indicating the number of sub-samples
#' @param .n_boots A integer indicating the number of iterations (how many times to generate a random sample)
#' @param .replace Boolean flag (TRUE/FALSE) indicating whether to sample with replacement (defaults to FALSE)
#'
#' @return A list of length 2, containing average mean and SD for .metric based on all iterations 
#' @export 
#'
#' @examples 

boot_resample <- function(.data, .metric, .num_samples, .n_boots = 10000, .replace = FALSE) {
  # Select just the column with your diversity index of interest 
  metric <- .data[[.metric]]
  
  # Create empty vectors to store output
  boot.result <- numeric(.n_boots)
  boot.sd <- numeric(.n_boots)
  
  # Set seed so that results are reproducible (otherwise, because it's random, results will differ each time)
  set.seed(123)
  for(i in 1:.n_boots) {
    boot.samp <- sample(metric, .num_samples, replace = .replace)  
    boot.result[i] <- mean(boot.samp, na.rm = TRUE)
    boot.sd[i] <- sd(boot.samp, na.rm = TRUE)
    
  }
  return(list(mean = mean(boot.result, na.rm = TRUE), sd = mean(boot.sd, na.rm = TRUE)))
}

