# Function to remove outliers from data frames
# Outliers are defined as those points whose value is greater than 1.5x the interquartile range (IQR)

remove_outliers <- function(.df, .y_var, ...) {
  
  .df %>% 
    
    # Group by site to calculate IQR for each site
    group_by(...) %>% 
    
    # Calculate the minimum and maximum values, beyond which a point will be considered an outlier
    mutate(minimum = median({{ .y_var }}) - 1.5 * IQR({{ .y_var }}),
           maximum = median({{ .y_var }}) + 1.5 * IQR({{ .y_var }})) %>% 
    
    # Filter out y values that fall outside the limits (are outliers)
    filter({{ .y_var }} > minimum,
           {{ .y_var }} < maximum)
  
}




# Original version of function (can only group by one variable) ----

#remove_outliers <- function(data, group_var, y_var) {
#  
#  data %>% 
#    
#    # Group by site to calculate IQR for each site
#    group_by(.data[[group_var]]) %>% 
#    
#    # Calculate the minimum and maximum values, beyond which a point will be considered an outlier
#    mutate(minimum = median(.data[[y_var]]) - 1.5 * IQR(.data[[y_var]]),
#           maximum = median(.data[[y_var]]) + 1.5 * IQR(.data[[y_var]])) %>% 
#    
#    # Filter out y values that fall outside the limits (are outliers)
#    filter(.data[[y_var]] > minimum,
#           .data[[y_var]] < maximum)
#  
#}